==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/SlowStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { SlowStochasticOscillatorIndicatorStrategy } from "./SlowStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
import { Brush } from "igniteui-react-core";
/**
 * @hidden
 */
var SlowStochasticOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SlowStochasticOscillatorIndicator, _super);
    function SlowStochasticOscillatorIndicator() {
        var _this = _super.call(this) || this;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 10;
        _this.trendLinePeriod = 3;
        return _this;
    }
    SlowStochasticOscillatorIndicator.prototype.get_yy = function () {
        return new SlowStochasticOscillatorIndicatorStrategy();
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.get_zb = function () {
        return SlowStochasticOscillatorIndicator.$;
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "zj", {
        get: function () {
            return typeGetValue(this.c(SlowStochasticOscillatorIndicator.zk));
        },
        set: function (a) {
            this.h(SlowStochasticOscillatorIndicator.zk, a);
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.y4 = function () {
        return this.zj;
    };
    SlowStochasticOscillatorIndicator.prototype.zd = function (a) {
        this.zj = a;
    };
    SlowStochasticOscillatorIndicator.$t = markType(SlowStochasticOscillatorIndicator, 'SlowStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    SlowStochasticOscillatorIndicator.zk = StrategyBasedIndicator.zg(14, SlowStochasticOscillatorIndicator.$);
    return SlowStochasticOscillatorIndicator;
}(StrategyBasedIndicator));
export { SlowStochasticOscillatorIndicator };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/SlowStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { SlowStochasticOscillatorIndicatorStrategy } from "./SlowStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
import { Brush } from "igniteui-react-core";
/**
 * @hidden
 */
var SlowStochasticOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SlowStochasticOscillatorIndicator, _super);
    function SlowStochasticOscillatorIndicator() {
        var _this = _super.call(this) || this;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 10;
        _this.trendLinePeriod = 3;
        return _this;
    }
    SlowStochasticOscillatorIndicator.prototype.bj = function () {
        return new SlowStochasticOscillatorIndicator();
    };
    SlowStochasticOscillatorIndicator.prototype.get_abq = function () {
        return new SlowStochasticOscillatorIndicatorStrategy();
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "abq", {
        get: function () {
            return this.get_abq();
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.get_ab3 = function () {
        return SlowStochasticOscillatorIndicator.$;
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "ab3", {
        get: function () {
            return this.get_ab3();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "acb", {
        get: function () {
            return typeGetValue(this.c(SlowStochasticOscillatorIndicator.acc));
        },
        set: function (a) {
            this.h(SlowStochasticOscillatorIndicator.acc, a);
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.abw = function () {
        return this.acb;
    };
    SlowStochasticOscillatorIndicator.prototype.ab5 = function (a) {
        this.acb = a;
    };
    SlowStochasticOscillatorIndicator.$t = markType(SlowStochasticOscillatorIndicator, 'SlowStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    SlowStochasticOscillatorIndicator.acc = StrategyBasedIndicator.ab8(14, SlowStochasticOscillatorIndicator.$);
    return SlowStochasticOscillatorIndicator;
}(StrategyBasedIndicator));
export { SlowStochasticOscillatorIndicator };
